==> nuxt-use-async-data-wrapper-1.0.0.tgz: package/lib/index.js <==
import { useAsyncData } from 'nuxt/app';
import { computed, unref } from 'vue';
/**
 * Wraps an object's Promise-returning functions to integrate with Nuxt's useAsyncData.
 *
 * It transforms the functions of the provided object into functions that can be used within a Nuxt application,
 * leveraging the reactivity and data fetching capabilities of useAsyncData.
 *
 * @template T - The type of the object.
 * @param obj - The object containing functions that return Promises.
 * @returns An object with the same function names as the original object, but wrapped to work with useAsyncData.
 *
 * @example
 * ```typescript
 * const originalObject = {
 *   async fetchData() { ... },
 *   async getItem(id: number) { ... },
 * };
 * const wrappedObject = useAsyncDataWrapper(originalObject);
 * ```
 */
export function useAsyncDataWrapper(obj) {
    const composable = {};
    const proto = Object.getPrototypeOf(obj);
    // Get function names from the object's prototype, excluding the constructor
    const functionNames = Object.getOwnPropertyNames(proto).filter(key => key !== 'constructor' && typeof obj[key] === 'function');
    for (const key of functionNames) {
        // Bind the function to preserve context
        const originalFunction = obj[key].bind(obj);
        // Create the wrapped function
        composable[key] = ((...args) => {
            let argsSupplier;
            let options;
            if (typeof args[0] === 'function') {
                // Function with arguments: first argument is argsSupplier, second is options
                argsSupplier = args[0];
                options = args[1];
            }
            else {
                // Function without arguments: options may be the first argument
                options = args[0];
            }
            if (argsSupplier) {
                // For functions with arguments
                // Reactive reference to arguments
                const argsRef = computed(() => argsSupplier());
                // Unique key for useAsyncData
                const dataKeyRef = computed(() => `${key}-${JSON.stringify(argsRef.value)}`);
                // Call useAsyncData with the generated key and function
                const asyncDataResult = useAsyncData(dataKeyRef.value, () => originalFunction(...unref(argsRef)), {
                    // Re-execute when arguments change
                    watch: [argsRef],
                    // Spread additional options
                    ...options,
                });
                return asyncDataResult;
            }
            else {
                // For functions without arguments
                const asyncDataResult = useAsyncData(key, () => originalFunction(), {
                    // Spread additional options
                    ...options,
                });
                return asyncDataResult;
            }
        });
    }
    return composable;
}

==> nuxt-use-async-data-wrapper-1.1.0.tgz: package/lib/index.js <==
import { useAsyncData } from 'nuxt/app';
import { computed, unref } from 'vue';
/**
 * Wraps an object's Promise-returning functions to integrate with Nuxt's useAsyncData.
 *
 * It transforms the functions of the provided object into functions that can be used within a Nuxt application,
 * leveraging the reactivity and data fetching capabilities of useAsyncData.
 *
 * @template T - The type of the object.
 * @param obj - The object containing functions that return Promises.
 * @returns An object with the same function names as the original object, but wrapped to work with useAsyncData.
 *
 * @example
 * ```typescript
 * const originalObject = {
 *   async fetchData() { ... },
 *   async getItem(id: number) { ... },
 * };
 * const wrappedObject = useAsyncDataWrapper(originalObject);
 * ```
 */
export function useAsyncDataWrapper(obj) {
    const composable = {};
    const proto = Object.getPrototypeOf(obj);
    // Get function names from the object's prototype, excluding the constructor
    const functionNames = Object.getOwnPropertyNames(proto).filter(key => key !== 'constructor' && typeof obj[key] === 'function');
    for (const key of functionNames) {
        // Bind the function to preserve context
        const originalFunction = obj[key].bind(obj);
        // Create the wrapped function
        composable[key] = ((...args) => {
            let argsSupplier;
            let options;
            if (typeof args[0] === 'function') {
                // Function with arguments: first argument is argsSupplier, second is options
                argsSupplier = args[0];
                options = args[1];
            }
            else {
                // Function without arguments: options may be the first argument
                options = args[0];
            }
            if (argsSupplier) {
                // For functions with arguments
                // Reactive reference to arguments
                const argsRef = computed(() => argsSupplier());
                // Unique key for useAsyncData
                const dataKeyRef = computed(() => `${key}-${JSON.stringify(argsRef.value)}`);
                // Call useAsyncData with the generated key and function
                const asyncDataResult = useAsyncData(dataKeyRef.value, () => {
                    const result = originalFunction(...unref(argsRef));
                    // Ensure we return a Promise
                    return result instanceof Promise ? result : Promise.resolve(result);
                }, {
                    // Re-execute when arguments change
                    watch: [argsRef],
                    // Spread additional options
                    ...options,
                });
                return asyncDataResult;
            }
            else {
                // For functions without arguments
                const asyncDataResult = useAsyncData(key, () => {
                    const result = originalFunction();
                    // Ensure we return a Promise
                    return result instanceof Promise ? result : Promise.resolve(result);
                }, {
                    // Spread additional options
                    ...options,
                });
                return asyncDataResult;
            }
        });
    }
    return composable;
}
